Package: leaflet.extras2
Type: Package
Title: Extra Functionality for 'leaflet' Package
Version: 1.3.2
Authors@R: c(
      person("Gatscha", "Sebastian", email = "sebastian_gatscha@gmx.at", role = c("aut", "cre")),
      person("Ricardo Rodrigo", "Basa", email = "radbasa@gmail.com", role = c("ctb")),
      person(c("Jeffrey", "O"), "Hanson", email = "jeffrey.hanson@uqconnect.edu.au", role = c("ctb"), comment = c(ORCID = "0000-0002-4716-6134"))
    )
Description: Several 'leaflet' plugins are integrated, which are available as extension to the 'leaflet' package.
License: GPL-3 | file LICENSE
Encoding: UTF-8
LazyData: true
Depends: R (>= 3.5.0), leaflet (>= 2.0.0)
Imports: htmltools, magrittr, utils
Suggests: jsonlite, shiny, sf, yyjsonr, sp, testthat (>= 3.1.7),
        fontawesome, htmlwidgets, grDevices, xfun, covr, curl
URL: https://trafficonese.github.io/leaflet.extras2/,
        https://github.com/trafficonese/leaflet.extras2
BugReports: https://github.com/trafficonese/leaflet.extras2/issues
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2025-08-27 12:57:58 UTC; kona1
Author: Gatscha Sebastian [aut, cre],
  Ricardo Rodrigo Basa [ctb],
  Jeffrey O Hanson [ctb] (ORCID: <https://orcid.org/0000-0002-4716-6134>)
Maintainer: Gatscha Sebastian <sebastian_gatscha@gmx.at>
Repository: CRAN
Date/Publication: 2025-08-27 15:10:08 UTC
Built: R 4.6.0; ; 2026-04-29 04:23:03 UTC; unix
