# Generated by roxygen2: do not edit by hand

S3method("[",leaflet_mapkey_icon_set)
export(addAntpath)
export(addArrowhead)
export(addBuildings)
export(addClusterCharts)
export(addContextmenu)
export(addDivicon)
export(addEasyprint)
export(addGIBS)
export(addGeosearch)
export(addHeightgraph)
export(addHexbin)
export(addHistory)
export(addItemContextmenu)
export(addLabelgun)
export(addLatLngMoving)
export(addLayerGroupCollision)
export(addLayerGroupConditional)
export(addLeafletsync)
export(addLeafletsyncDependency)
export(addMapkeyMarkers)
export(addMovingMarker)
export(addOpenweatherCurrent)
export(addOpenweatherTiles)
export(addPlayback)
export(addReachability)
export(addSidebar)
export(addSidebyside)
export(addSpinner)
export(addStationMoving)
export(addTangram)
export(addTimeslider)
export(addVelocity)
export(addWMS)
export(antpathOptions)
export(arrowheadOptions)
export(clearAntpath)
export(clearArrowhead)
export(clearConditionalLayers)
export(clearFuture)
export(clearHexbin)
export(clearHistory)
export(closeSidebar)
export(clusterchartOptions)
export(context_mapmenuItems)
export(context_markermenuItems)
export(context_menuItem)
export(disableContextmenu)
export(easyprintMap)
export(easyprintOptions)
export(enableContextmenu)
export(geosearchOptions)
export(geosearchProvider)
export(goBackHistory)
export(goForwardHistory)
export(heightgraphOptions)
export(hexbinOptions)
export(hideContextmenu)
export(hideHexbin)
export(historyOptions)
export(insertItemContextmenu)
export(isSynced)
export(leafletsyncOptions)
export(makeMapkeyIcon)
export(mapkeyIconList)
export(mapkeyIcons)
export(mapmenuItems)
export(markermenuItems)
export(menuItem)
export(moveToMoving)
export(movingMarkerOptions)
export(openSidebar)
export(openweatherCurrentOptions)
export(openweatherOptions)
export(pauseMoving)
export(playbackOptions)
export(reachabilityOptions)
export(removeAntpath)
export(removeArrowhead)
export(removeConditionalLayer)
export(removeEasyprint)
export(removeGeosearch)
export(removeItemContextmenu)
export(removePlayback)
export(removeReachability)
export(removeSidebar)
export(removeSidebyside)
export(removeTimeslider)
export(removeVelocity)
export(removeallItemsContextmenu)
export(resumeMoving)
export(setBuildingData)
export(setBuildingStyle)
export(setDate)
export(setDisabledContextmenu)
export(setOptionsVelocity)
export(setTransparent)
export(showContextmenu)
export(showHexbin)
export(sidebar_pane)
export(sidebar_tabs)
export(startMoving)
export(startSpinner)
export(stopMoving)
export(stopSpinner)
export(timesliderOptions)
export(unsync)
export(updateBuildingTime)
export(updateHexbin)
export(velocityOptions)
import(leaflet)
importFrom(grDevices,colorRampPalette)
importFrom(htmltools,findDependencies)
importFrom(htmltools,htmlDependency)
importFrom(htmltools,tagGetAttribute)
importFrom(htmltools,tagList)
importFrom(htmltools,tags)
importFrom(magrittr,"%>%")
importFrom(utils,adist)
importFrom(utils,globalVariables)
importFrom(utils,packageVersion)
